# covidcasev

<p>The goal of this project is to visualize the number of infected people by country due to Covid-19.</p>
<p>Using a OWID dataset, covidcasev can visualize the number of infected people by country due to Covid-19.</p>
The OWID dataset is downloadable from:</p>
https://github.com/owid/covid-19-data/tree/master/public/data/vaccinations

<img src="https://github.com/yugo-Ishihara/covidcasev/blob/main/result.png">


<h1>
  How to install covidcasev on Linux, MacOS, or WSL on Windows
</h1>
$ pip install covidcasev

<h1>
  How to run covidcasev 
</h1>
$ covidcasev country <br>
ex. $ covidcasev Japan
